@@ -3,8 +3,6 @@ package com.fewlaps.flone.view.activity;
 import android.content.Intent;
 import android.os.Bundle;
 import android.os.Handler;
-import android.support.v4.content.IntentCompat;
-import android.view.KeyEvent;
 import android.view.Menu;
 import android.view.MenuItem;
 import android.view.MotionEvent;
@@ -14,15 +12,11 @@ import android.widget.SeekBar;
 import android.widget.TextView;
 
 import com.fewlaps.flone.R;
-import com.fewlaps.flone.data.bean.PhoneSensorsData;
-import com.fewlaps.flone.io.bean.ActualArmedData;
-import com.fewlaps.flone.io.bean.ArmedDataChangeRequest;
 import com.fewlaps.flone.io.bean.DroneSensorData;
-import com.fewlaps.flone.io.communication.RCSignals;
+import com.fewlaps.flone.io.input.phone.PhoneInputData;
 import com.fewlaps.flone.io.input.phone.PhoneOutputData;
 import com.fewlaps.flone.io.input.phone.ScreenThrottleData;
 import com.fewlaps.flone.service.DroneService;
-import com.fewlaps.flone.view.dialog.SendRawDataDialog;
 import com.squareup.phrase.Phrase;
 
 import de.greenrobot.event.EventBus;
@@ -45,7 +39,6 @@ public class FlyActivity extends BaseActivity {
     private View throttleTouchableRL;
     private View throttleControlLL;
     private TextView throttleControlPercentageTV;
-    private View disarmedLayout;
 
     private SeekBar phoneHeading;
     private SeekBar phonePitch;
@@ -57,7 +50,6 @@ public class FlyActivity extends BaseActivity {
     private SeekBar dataSentPitch;
     private SeekBar dataSentRoll;
 
-    private boolean armed = DroneService.ARMED_DEFAULT;
 
     @Override
     protected void onCreate(Bundle savedInstanceState) {
@@ -69,7 +61,6 @@ public class FlyActivity extends BaseActivity {
         throttleTouchableRL = findViewById(R.id.rl_throttle_touchable);
         throttleControlLL = findViewById(R.id.ll_throttle_control);
         throttleControlPercentageTV = (TextView) findViewById(R.id.tv_throttle_control_percentage);
-        disarmedLayout = findViewById(R.id.root_disarmed);
 
         phoneHeading = (SeekBar) findViewById(R.id.sb_phone_heading);
         phonePitch = (SeekBar) findViewById(R.id.sb_phone_pitch);
@@ -81,17 +72,29 @@ public class FlyActivity extends BaseActivity {
         dataSentPitch = (SeekBar) findViewById(R.id.sb_data_sent_pitch);
         dataSentRoll = (SeekBar) findViewById(R.id.sb_data_sent_roll);
 
+        findViewById(R.id.bt_connect).setOnClickListener(new View.OnClickListener() {
+            @Override
+            public void onClick(View view) {
+                FlyActivity.this.startService(new Intent(FlyActivity.this, DroneService.class));
+                EventBus.getDefault().post(DroneService.ACTION_CONNECT);
+            }
+        });
+        findViewById(R.id.bt_disconnect).setOnClickListener(new View.OnClickListener() {
+            @Override
+            public void onClick(View view) {
+                EventBus.getDefault().post(DroneService.ACTION_DISCONNECT);
+            }
+        });
+
         throttleBackgroundV.setOnTouchListener(new View.OnTouchListener() {
             @Override
             public boolean onTouch(View v, MotionEvent event) {
-                int action = event.getAction();
-                if (action == MotionEvent.ACTION_MOVE || action == MotionEvent.ACTION_DOWN) {
-                    ScreenThrottleData.instance.setThrottle((int) event.getY());
-                } else if (action == MotionEvent.ACTION_UP) {
-                    ScreenThrottleData.instance.setThrottleAtMid();
-                }
+                ScreenThrottleData.instance.setThrottle((int) event.getY());
 
-                updateThrottleLabel();
+                double y = ScreenThrottleData.instance.getThrottleScreenPosition() - throttleControlLL.getHeight() + throttleTouchableRL.getPaddingTop();
+                throttleControlLL.setY((int) y);
+
+                updateThrottleLabel(ScreenThrottleData.instance.getThrottlePorcentage());
 
                 return true;
             }
@@ -105,29 +108,13 @@ public class FlyActivity extends BaseActivity {
             }
         }, 100);
 
-        updateThrottleLabel();
-
-        EventBus.getDefault().post(DroneService.ACTION_GET_ARMED);
+        updateThrottleLabel(0);
     }
 
     @Override
     protected void onResume() {
         super.onResume();
         EventBus.getDefault().register(this);
-
-        updateArmedLayer();
-
-        if (!armed) {
-            setThrottleToZero();
-        }
-    }
-
-    private void updateArmedLayer() {
-        if (armed) {
-            disarmedLayout.setVisibility(View.INVISIBLE);
-        } else {
-            disarmedLayout.setVisibility(View.VISIBLE);
-        }
     }
 
     @Override
@@ -148,14 +135,6 @@ public class FlyActivity extends BaseActivity {
             case R.id.action_calibration:
                 startActivity(new Intent(this, CalibrationActivity.class));
                 return true;
-            case R.id.action_preferences:
-                return true;
-            case R.id.action_send_raw_data:
-                SendRawDataDialog.showDialog(this);
-                return true;
-            case R.id.action_disconnect:
-                shutDownAndQuitActivity();
-                return true;
             default:
                 return super.onOptionsItemSelected(item);
         }
@@ -167,10 +146,12 @@ public class FlyActivity extends BaseActivity {
         droneRoll.setProgress((int) data.getRoll() + 180);
     }
 
-    public void onEventMainThread(PhoneSensorsData data) {
+    public void onEventMainThread(PhoneInputData data) {
         phoneHeading.setProgress((int) data.getHeading() + 180);
         phonePitch.setProgress((int) data.getPitch() + 180);
         phoneRoll.setProgress((int) data.getRoll() + 180);
+
+//        phoneSensorsSB.append(getString(R.string.throttle) + ": " + ScreenThrottleData.instance.getThrottle() + "\n");
     }
 
     public void onEventMainThread(PhoneOutputData data) {
@@ -179,49 +160,8 @@ public class FlyActivity extends BaseActivity {
         dataSentRoll.setProgress((int) data.getRoll() - 1000);
     }
 
-    public void onEventMainThread(ActualArmedData armed) {
-        this.armed = armed.isArmed();
-        updateArmedLayer();
-    }
-
-    private void updateThrottleLabel() {
-        double y = ScreenThrottleData.instance.getThrottleScreenPosition() - throttleControlLL.getHeight() + throttleTouchableRL.getPaddingTop();
-        throttleControlLL.setY((int) y);
-
-        CharSequence formatted = Phrase.from(getString(R.string.trottle_now)).put("value", ScreenThrottleData.instance.getThrottlePorcentage()).format();
+    private void updateThrottleLabel(int throttlePorcentage) {
+        CharSequence formatted = Phrase.from(getString(R.string.trottle_now)).put("value", throttlePorcentage).format();
         throttleControlPercentageTV.setText(formatted);
     }
-
-    @Override
-    public boolean onKeyDown(int keyCode, KeyEvent event) {
-        if (event.getAction() == KeyEvent.ACTION_DOWN) {
-            if ((keyCode == KeyEvent.KEYCODE_VOLUME_UP)) {
-                EventBus.getDefault().post(new ArmedDataChangeRequest(true));
-                setThrottleToZero();
-            } else if ((keyCode == KeyEvent.KEYCODE_VOLUME_DOWN)) {
-                EventBus.getDefault().post(new ArmedDataChangeRequest(false));
-                setThrottleToZero();
-            }
-        }
-        return true;
-    }
-
-    private void shutDownAndQuitActivity() {
-        EventBus.getDefault().post(new ArmedDataChangeRequest(false));
-        new Handler().postDelayed(new Runnable() {
-            @Override
-            public void run() {
-                EventBus.getDefault().post(DroneService.ACTION_DISCONNECT);
-                Intent i = new Intent(FlyActivity.this, DronesListActivity.class);
-                i.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK | IntentCompat.FLAG_ACTIVITY_CLEAR_TASK);
-                finish();
-                startActivity(i);
-            }
-        }, 1000);
-    }
-
-    private void setThrottleToZero() {
-        ScreenThrottleData.instance.setThrottle(RCSignals.RC_MIN);
-        updateThrottleLabel();
-    }
 }
